@@ -88,9 +88,12 @@ def update(**kwargs):
             time.sleep(interval)
     finally:
 	pidfile.close()
-	os.remove(configs[0]['pidfile'])
+	try:
+		os.remove(configs[0]['pidfile'])
+	except:
+		pass
 
 
 
-__version__ = '0.8.5'
+__version__ = '0.9'
 
