@@ -15,7 +15,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from twitter import Api
+import tweepy
+from tweepy.error import TweepError
 import readrss
 from shortener import services, ShortenerException
 from httplib import BadStatusLine
@@ -65,17 +66,16 @@ class Microblog(object):
             else:
                 txt = it['title'][0:144] + " " + tiny(it['link'])
             try:
-                status = self.api.PostUpdate(txt)
+                status = self.api.update_status(txt)
                 self.rss.updateLastRead(it)
                 log.info(status.text + " posted on " + self.alias)
                 time.sleep(5)
 
-            except (BadStatusLine, HTTPError, URLError), e:
+            except (TweepError), e:
                 try:
-                    resp = simplejson.loads(e.read())
-                    log.debug(resp['error'])
-                    if resp['error'] == 'Status is a duplicate.':
-                        self.rss.updateLastRead(it)                        
+                    log.debug(e.reason + ' - ' + txt)
+                    if e.reason == 'Status is a duplicate.' or e.reason == 'Twitter error response: status code = 411':
+                        self.rss.updateLastRead(it)
                 except:
                     pass
                 #lets try in the next time
@@ -93,7 +93,7 @@ class WordpressAPI(object):
         return status
 
 
-class IdenticaAPI(Api):
+class IdenticaAPI(object):
 
     _API_REALM = 'Identi.ca API'
 
@@ -135,14 +135,14 @@ class IdenticaAPI(Api):
 
 
 class Twitter(Microblog):
-    def __init__(self,  alias, url, username, passwd, mode='title', items = 5, shortener='tinyurl'):
-        self.alias = alias
+    def __init__(self, url='',service='',section='', interval='',mode='title', items = 5, shortener='tinyurl',oauth_secret='',oauth_token='',consumer_secret='',consumer_key='',pidfile=''):
         self.mode = mode
+        self.alias = section
         self.url = url
         self.items = items
-        self.username = username
-        self.passwd = passwd
-        self.api = Api(username=self.username, password=self.passwd)
+	auth = tweepy.OAuthHandler(consumer_key, consumer_secret)
+	auth.set_access_token(oauth_token, oauth_secret)
+        self.api = tweepy.API(auth)
         self.rss = readrss.parse(url,self.__class__.__name__.lower(), self.alias)
         self.shortener = services[shortener]()
 
@@ -193,7 +193,7 @@ class Wordpress(Microblog):
 class service(object):
     def __init__(self,**kwargs):
         if kwargs['service'] == 'twitter':
-            self.micro = Twitter(kwargs['section'], kwargs['url'],kwargs['username'],kwargs['password'],kwargs['mode'],kwargs['items'],kwargs['shortener'])
+            self.micro = Twitter(**kwargs)
         elif kwargs['service'] == 'identica':
             self.micro = Identica(kwargs['section'], kwargs['url'],kwargs['username'],kwargs['password'],kwargs['mode'],kwargs['items'],kwargs['shortener'])
         elif kwargs['service'] == 'wordpress':
