@@ -18,7 +18,13 @@
 import feedparser, pickle, time
 import os.path
 from os import mkdir
-import md5
+try:
+    import hashlib
+    md = hashlib.md5()
+except ImportError:
+    # for Python << 2.5
+    import md5
+    md = md5.new()
 import logging
 log = logging.getLogger(__name__)
 log.setLevel(logging.DEBUG)
@@ -35,11 +41,11 @@ class parse(object):
         self.alias = alias
         self.directory = os.path.expanduser("~/.feed2mb/")
 
-        md5name = md5.md5(self.feed_url + self.service).hexdigest()
+        md.update(self.feed_url + self.service)
+	md5name = md.hexdigest()
         self.filename = self.directory + md5name
 
     def updateLastRead(self,item=None):
-	log.info('updating last time that the feed was read')
         if not os.path.exists(self.directory):
             mkdir(self.directory)
         output = open(self.filename, 'wb')
@@ -55,6 +61,8 @@ class parse(object):
                 key = 'updated_parsed'
             if item[key] is None:
                 raise FeedDateTimeException("Your item on " + self.alias+ " doesn't appear to have a valid date of publication. Feed2mb needs it!")
+            log.info('updating last time that the feed was read to ' + time.strftime("%Y-%m-%d %H:%M:%S",item[key]))
+
             pickle.dump(item[key], output)
         output.close()
 
@@ -68,7 +76,7 @@ class parse(object):
             last_read = pickle.load(pick)
         except EOFError:
             return False
-	log.debug(self.alias + ' last read on: '+ time.strftime("%Y-%m-%d %H:%M:%S",last_read))
+	log.debug('source feed for ' + self.alias + ' last read on: '+ time.strftime("%Y-%m-%d %H:%M:%S",last_read))
         return last_read
 
 
